@@ -63,6 +63,7 @@ BEGIN {
       _NS_TB2PURL_
       _NS_TNRS_
       _NS_FIGTREE_
+      _NS_PHYLOMAP_
     );
     %EXPORT_TAGS = (
         'all'         => [@EXPORT_OK],
@@ -129,6 +130,7 @@ BEGIN {
               _NS_TB2PURL_
               _NS_TNRS_
               _NS_FIGTREE_
+              _NS_PHYLOMAP_
             )
         ]
     );
@@ -156,6 +158,7 @@ sub _NS_PHYLOXML_ () { 'http://www.phyloxml.org/1.10/terms#' }
 sub _NS_TB2PURL_ ()  { 'http://purl.org/phylo/treebase/phylows/' }
 sub _NS_TNRS_ ()     { 'http://phylotastic.org/tnrs/terms#' }
 sub _NS_FIGTREE_ ()  { 'http://tree.bio.ed.ac.uk/software/figtree/terms#' }
+sub _NS_PHYLOMAP_ () { 'http://purl.org/phylo/phylomap/terms#' }
 
 our $NS = {
     'tnrs' => _NS_TNRS_(),
